"use strict";
// MIT License
//
// Copyright (c) 2021 Augustin Husson
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
Object.defineProperty(exports, "__esModule", { value: true });
exports.KVSearchExtension = exports.kvSearchLanguage = void 0;
const language_1 = require("@codemirror/language");
const parser_1 = require("./grammar/parser");
const highlight_1 = require("@codemirror/highlight");
const complete_1 = require("./complete/complete");
exports.kvSearchLanguage = language_1.LRLanguage.define({
    parser: parser_1.parser.configure({
        top: 'KVSearch',
        props: [
            (0, highlight_1.styleTags)({
                'And Or': highlight_1.tags.logicOperator,
                'Neq EqlRegex EqlSingle': highlight_1.tags.arithmeticOperator,
            })
        ]
    }),
    languageData: {
        closeBrackets: { brackets: ['('] },
    }
});
class KVSearchExtension {
    constructor(objects) {
        this.complete = new complete_1.Complete(objects);
    }
    asExtension() {
        const language = exports.kvSearchLanguage;
        let extension = [language];
        const completion = language.data.of({
            autocomplete: (context) => {
                return this.complete.kvSearch(context);
            },
        });
        extension = extension.concat(completion);
        return extension;
    }
}
exports.KVSearchExtension = KVSearchExtension;
